@@ -3,11 +3,12 @@ Provides utilities related to:
 - querying available target languages,
 - calling proc-like functions, where target language is specified programmatically
 """
+
 import pathlib
 import importlib
 
 
-def _remove_prefix(in_str, in_prefix):
+def _remove_prefix(in_str: str, in_prefix: str) -> str:
     assert in_str.startswith(in_prefix)
     return in_str[len(in_prefix) :]
 
@@ -20,21 +21,21 @@ _LANGUAGE_IDS = frozenset(
 )
 
 
-def get_target_languages():
+def get_target_languages() -> frozenset[str]:
     """
     returns the set of ids of all supported target languages
     """
     return _LANGUAGE_IDS
 
 
-def is_language_supported(in_language_id):
+def is_language_supported(in_language_id: str) -> bool:
     """
     checks is language with given id is supported
     """
     return in_language_id in get_target_languages()
 
 
-def _to_module_name(in_id):
+def _to_module_name(in_id: str) -> str:
     return _MODULE_PREFIX + in_id
 
 
@@ -44,7 +45,7 @@ _ALL_MODULES_DICT = {
 }
 
 
-def proc(in_target_language_id, in_str, **kwargs):
+def proc(in_target_language_id: str, in_str: str, **kwargs) -> str:
     """
     returns a code in in_target_language_id displaying in_str
     """
